use super::Fat;
use crate::os::OperatingSystem;

/// Struct that houses functions for building the Volume Boot Record
pub struct Vbr {
    bytes: [u8; 512],
}

impl Vbr {
    pub fn from_os(os: &OperatingSystem, filesystem: &Fat) -> Self {
        let mut new_bytes = [0u8; 512];
        match os {
            OperatingSystem::IBMDOS200 => {
                new_bytes[..3].copy_from_slice(&os.get_vbr_jumpcode());
                new_bytes[3..11].copy_from_slice(os.get_oem_name());
                new_bytes[11..24].copy_from_slice(&filesystem.bpb_dos200());
                new_bytes[24..503].copy_from_slice(&os.get_vbr_bootcode());
                new_bytes[510] = 0x55;
                new_bytes[511] = 0xaa;
            }
            _ => (),
        }
        Vbr { bytes: new_bytes }
    }

    pub fn as_bytes(&self) -> [u8; 512] {
        self.bytes
    }
}
